[Webfunds-commits] java/webfunds/sox Errors.java

Ian Grigg iang@cypherpunks.ai
Thu, 30 Nov 2000 09:38:22 -0400 (AST)


iang        00/11/30 09:38:22

  Modified:    webfunds/sox Errors.java
  Log:
  2 new errors for distinct transaction types / withdrawal

Revision  Changes    Path
1.17      +11 -4     java/webfunds/sox/Errors.java

Index: Errors.java
===================================================================
RCS file: /home/webfunds/cvsroot/java/webfunds/sox/Errors.java,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -r1.16 -r1.17
--- Errors.java	2000/10/14 01:52:21	1.16
+++ Errors.java	2000/11/30 13:38:21	1.17
@@ -1,5 +1,5 @@
 /*
- * $Id: Errors.java,v 1.16 2000/10/14 01:52:21 iang Exp $
+ * $Id: Errors.java,v 1.17 2000/11/30 13:38:21 iang Exp $
  *
  * Copyright (c) Systemics Ltd 1995-1999 on behalf of
  * the WebFunds Development Team.  All Rights Reserved.
@@ -46,9 +46,10 @@
     public static final int ERROR_DEP_ALREADY          = 19; // did already set
 
     public static final int ERROR_NOT_PERMITTED        = 20; // limited account
+    public static final int ERROR_NOT_SUPPORTED        = 21; // by this Ivan
 
     /**
      *  30-39 are bad arguments within a deposit or payment.
      */
     public static final int ERROR_NOT_A_PAYMENT        = 30;
     public static final int ERROR_PAYMENT_NOT_SIGNED   = 31;
@@ -60,6 +61,8 @@
     public static final int ERROR_NOT_SOURCE_KHID      = 37;
     public static final int ERROR_ILLEGAL_PID          = 38;
     public static final int ERROR_ILLEGAL_DID          = 39;
+    public static final int ERROR_NOT_ENUF             = 40;  // withdrawal
+    public static final int ERROR_NOT_PROTO            = 41;  // withdrawal
 
 
     /**
@@ -112,7 +115,8 @@
                 "deposited already (did has previously been used)",
 
     /* 20 */    "operation not permitted on this account",
-                    "", "", "", "", "", "", "", "", "", 
+                "unsupported transaction type on this issuer",
+                        "", "", "", "", "", "", "", "", 
 
     /* 30 */    "Message within Deposit is not a Payment",
                 "payment not signed",
@@ -125,7 +129,10 @@
                 "illegal PID",
                 "illegal DID",
         
-    /* 40 */    "", "", "", "", "", "", "", "", "", "", 
+    /* 40 */    "payment amount does not match proto amount",
+                "proto invalid",
+                        "", "", "", "", "", "", "", "", 
+
     /* 50 */    "", "", "", "", "", "", "", "", "", "", 
         
     /* 60 */    "no such KHID",
@@ -46,9 +46,10 @@
 
     /**
-     *  30-39 are bad arguments within a deposit or payment.
+     *  30-40 are bad arguments within a deposit or payment.
      */
     public static final int ERROR_NOT_A_PAYMENT        = 30;